package fr.sanchezm.attestationsCovid19.data.db.dao

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.google.gson.Gson
import com.google.gson.reflect.TypeToken
import fr.sanchezm.attestationsCovid19.data.db.entity.Attestation
import fr.sanchezm.attestationsCovid19.utilities.PdfUtils
import java.io.File

class AttestationDao(private val path: String) {

    private var _attestations = MutableLiveData<ArrayList<Attestation>>()
    private var fileName = "attestation.db"
    private val type = object : TypeToken<ArrayList<Attestation>>() {}.type

    fun getAttestations() : LiveData<ArrayList<Attestation>> =
        _attestations

    fun getAttestation(id: Int): Attestation? =
        _attestations.value?.elementAt(id)

    fun addAttestation(attestation: Attestation) {
        _attestations.value?.add(attestation)
        save()
    }

    fun getAttestation(createAt: Long): Attestation? {
        _attestations.value?.forEach {
            if (it.createAt == createAt)
                return@getAttestation it
        }
        return null
    }

    init {
        load()
    }

    private fun load() {
        val file = File("$path/$fileName")

        if (file.exists()) {
            _attestations.value = Gson().fromJson(file.readText(Charsets.UTF_8), type)
        }
        _attestations.value?.forEach {
            val filePath = PdfUtils.getInstance()?.getPath(it.createAt)

            if (filePath != null && !File(filePath).exists()) {
                _attestations.value!!.remove(it)
            }
        }
    }

    private fun save() {
        File("$path/$fileName").writeText(Gson().toJson(_attestations.value))
    }

}

//@Dao
//interface AttestationDao {
//    @Insert
//    fun insert(attestation: Attestation)
//
//    @Query(value = "SELECT * FROM attestation WHERE id = $CURRENT_ATTESTATION_ID")
//    fun getAttestation(): LiveData<Attestation>
//}